@@ -2,7 +2,7 @@
 #coding: utf-8
 
 """
-COPYRIGHT (c) 2009-2013
+COPYRIGHT (c) 2009-2014
 
 LICENSE
 Permission is hereby granted, free of charge, to any person obtaining a copy
@@ -51,11 +51,13 @@ class Pytddmon:
             self,
             file_finder,
             monitor,
-            project_name="<pytddmon>"
+            project_name="<pytddmon>",
+            pulse_disabled=False
     ):
         self.file_finder = file_finder
         self.project_name = project_name
         self.monitor = monitor
+        self.pulse_disabled = pulse_disabled
         self.change_detected = False
 
         self.total_tests_run = 0
@@ -297,10 +299,17 @@ def run_suite(suite):
 
 def import_tkinter():
     """imports tkinter from python 3.x or python 2.x"""
-    if not ON_PYTHON3:
-        import Tkinter as tkinter
-    else:
-        import tkinter
+    try:
+        if not ON_PYTHON3:
+            import Tkinter as tkinter
+        else:
+            import tkinter
+    except ImportError as e:
+        sys.stderr.write('Cannot import tkinter. Please install it using your system ' +
+                         'package manager, since tkinter is not available on PyPI. On Ubuntu : ' +
+                         '`sudo apt-get install python-tk`.\n' +
+                         'The actual error was "{0}"\n'.format(e))
+        raise SystemExit(1)
     return tkinter
 
 
@@ -360,7 +369,7 @@ class TkGUI(object):
         self.pytddmon = pytddmon
         self.tkinter = tkinter
         self.tkFont = tkFont
-        self.color_picker = ColorPicker()
+        self.color_picker = ColorPicker(pulse_disabled=pytddmon.pulse_disabled)
         self.root = None
         self.building_root()
         self.title_font = None
@@ -475,10 +484,14 @@ class TkGUI(object):
         if ON_WINDOWS:
             win.attributes("-toolwindow", 1)
         win.title('Details')
+        win.protocol('WM_DELETE_WINDOW', self.when_message_window_x)
         self.message_window = win
         self.text = self.tkinter.Text(win)
         self.message_window.withdraw()
 
+    def when_message_window_x(self):
+        self.message_window.withdraw()
+
     def update_text_window(self):
         """inserts/replaces the log message in the text widget"""
         text = self.text
@@ -492,7 +505,7 @@ class TkGUI(object):
     def display_log_message(self, _arg):
         """displays/close the log message from pytddmon in a window"""
         if self.message_window.state() == 'normal':
-            self.message_window.state('iconic')
+            self.message_window.withdraw()
         else:
             self.message_window.state('normal')
 
@@ -528,9 +541,10 @@ class ColorPicker:
         (False, 'gray'): '555'
     }
 
-    def __init__(self):
+    def __init__(self, pulse_disabled=False):
         self.color = 'green'
         self.light = True
+        self.pulse_disabled = pulse_disabled
 
     def pick(self):
         """returns the tuple (light, color) with the types(bool ,str)"""
@@ -538,6 +552,8 @@ class ColorPicker:
 
     def pulse(self):
         """updates the light state"""
+        if self.pulse_disabled:
+            return
         self.light = not self.light
 
     def reset_pulse(self):
@@ -577,8 +593,14 @@ def parse_commandline():
     parser.add_option(
         "--log-path",
         help='Instead of writing to "pytddmon.log" in --log-and-exit, write to LOG_PATH instead.')
+    parser.add_option(
+        "--no-pulse",
+        dest="pulse_disabled",
+        action="store_true",
+        default=False,
+        help='Disable the "heartbeating colorshift" of pytddmon.')
     (options, args) = parser.parse_args()
-    return args, options.log_and_exit, options.log_path
+    return args, options.log_and_exit, options.log_path, options.pulse_disabled
 
 
 def build_monitor(file_finder):
@@ -605,7 +627,7 @@ def run():
     sys.path[:0] = [cwd]
 
     # Command line argument handling
-    (static_file_set, test_mode, test_output) = parse_commandline()
+    (static_file_set, test_mode, test_output, pulse_disabled) = parse_commandline()
 
     # What files to monitor?
     if not static_file_set:
@@ -621,7 +643,8 @@ def run():
     pytddmon = Pytddmon(
         file_finder,
         monitor,
-        project_name=os.path.basename(cwd)
+        project_name=os.path.basename(cwd),
+        pulse_disabled=pulse_disabled
     )
 
     # Start the engine!
